@@ -711,7 +711,7 @@ class MVTools:
 
         self.is_gray = self.planes == [0]
 
-        self.mv_plane = planes_to_mvtools(planes)
+        self.mv_plane = planes_to_mvtools(self.planes)
 
         self.chroma = self.mv_plane != 0
 
@@ -1117,12 +1117,14 @@ class MVTools:
         thSCD1, thSCD2 = thSCD
 
         thSCD1 = fallback(thSCD1, round(0.35 * thSAD + 260) if self.params_curve else thSAD // 2)
-        thSCD2 = int(fallback(thSCD2, 51) / 100 * 255)
+        thSCD2 = fallback(thSCD2, 51)
 
         if not 1 <= thSCD2 <= 100:
             raise CustomOverflowError(
                 '"thSCD[1]" must be between 1 and 100 (inclusive)!', self.__class__.degrain
             )
+        
+        thSCD2 = int(thSCD2 / 100 * 255)
 
         vect_b, vect_f = self.get_vectors_bf()
 
@@ -1182,6 +1184,6 @@ class MVTools:
 
         return tuple(  # type: ignore[return-value]
             None if ptype is PelType.NONE else ptype(  # type: ignore[misc]
-                clip, self.pel, default=PelType.WIENER if is_ref else PelType.BICUBIC
+                clip, self.pel, PelType.WIENER if is_ref else PelType.BICUBIC
             ) for is_ref, ptype, clip in zip((False, True), pel_type, (pref, ref))
         )
